## 如何运行测试项目

### 方式一
在项目节点上右击，选择"运行",即可立即运行该测试项目,如图
![运行项目](./img/run_project.png)

### 方式二

在项目节点上右击，选择"查看任务" -> 在查看任务页，单击"运行"按钮，即可，如图

1. ![查看任务](./img/view_task.png)

2. ![运行项目](./img/run_task.png) 